==> mighttpd2-4.0.3-237-x86_64.pkg.tar.zst: usr/share/haskell/register/mighttpd2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mighttpd2
version:              4.0.3
visibility:           public
id:                   mighttpd2-4.0.3-12hbTx1wzKl9Hgj0ndX3EB
key:                  mighttpd2-4.0.3-12hbTx1wzKl9Hgj0ndX3EB
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://kazu-yamamoto.github.io/mighttpd2/
synopsis:             High performance web server on WAI/warp
description:
    High performance web server to handle static
    files and CGI on WAI/warp.
    Reverse proxy functionality is also provided
    to connect web applications behind.

category:             Network, Web
abi:                  65c575195353faa61c0a3c9c861d600f
exposed:              True
exposed-modules:
    Program.Mighty Program.Mighty.ByteString Program.Mighty.Config
    Program.Mighty.Dhall.Option Program.Mighty.Network
    Program.Mighty.Parser Program.Mighty.Process Program.Mighty.Report
    Program.Mighty.Resource Program.Mighty.Route Program.Mighty.Signal
    Program.Mighty.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/mighttpd2-4.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mighttpd2-4.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mighttpd2-4.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/mighttpd2
hs-libraries:         HSmighttpd2-4.0.3-12hbTx1wzKl9Hgj0ndX3EB
depends:
    array-0.5.4.0 async-2.2.5-7zRWRGcsDHK4x7TGVl8w2c
    auto-update-0.1.6-B3ftYI2ey2r5el4bZgPHbB base-4.17.2.1
    byteorder-1.0.4-GnZZPnCtMLjHLa4McP5dl3 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-FZkso54i68UDZy9QWLkbnV
    conduit-1.3.6.1-5gNy7BQG7iKJKbtk0ojVYD
    conduit-extra-1.3.6-EKYs9mDn11i2A4ppI4Ndpg
    dhall-1.42.1-DWO4Pvog5na7T1dohK8osv directory-1.3.7.1
    filepath-1.4.2.2 http-date-0.0.11-D3J2PImuYP3ELKHPAHGZpy
    http-types-0.12.4-A1oxPTNXSXlBA9G2ubwbl6
    network-3.1.4.0-6CSLlS2XYBeLlFfm0MgCfu parsec-3.1.16.1
    resourcet-1.2.6-GnLJF89DOOQL8wsZDsu1Nb
    split-0.2.5-KcBaumhT6eFHklJKzsytdC
    streaming-commons-0.2.3.0-18n0yU3DoS0GNSvBxR5zoS text-2.0.2
    unix-2.7.3 unix-time-0.4.16-6XNkEunbRxSEoHJTfr64py
    unliftio-0.2.25.1-4ouS4p8u42FHJEBnZmJiqL
    unordered-containers-0.2.20-7moq3V15ycBgVs1tpEAw
    wai-3.2.4-Lttg4m4AEjdFXbTXCiChmz
    wai-app-file-cgi-3.1.10-KqYEVdGSeXEAwzKz3YoB1B
    warp-3.3.30-4zejg4UtDJIBTknYWtwpr5

haddock-interfaces:   /usr/share/doc/mighttpd2/html/mighttpd2.haddock
haddock-html:         /usr/share/doc/mighttpd2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> mighttpd2-4.0.3-238-x86_64.pkg.tar.zst: usr/share/haskell/register/mighttpd2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mighttpd2
version:              4.0.3
visibility:           public
id:                   mighttpd2-4.0.3-IE2lYHc8mOPHjC6L8fNsLS
key:                  mighttpd2-4.0.3-IE2lYHc8mOPHjC6L8fNsLS
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://kazu-yamamoto.github.io/mighttpd2/
synopsis:             High performance web server on WAI/warp
description:
    High performance web server to handle static
    files and CGI on WAI/warp.
    Reverse proxy functionality is also provided
    to connect web applications behind.

category:             Network, Web
abi:                  734963371ae5106bf98dec6e1af5dec5
exposed:              True
exposed-modules:
    Program.Mighty Program.Mighty.ByteString Program.Mighty.Config
    Program.Mighty.Dhall.Option Program.Mighty.Network
    Program.Mighty.Parser Program.Mighty.Process Program.Mighty.Report
    Program.Mighty.Resource Program.Mighty.Route Program.Mighty.Signal
    Program.Mighty.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/mighttpd2-4.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mighttpd2-4.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mighttpd2-4.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/mighttpd2
hs-libraries:         HSmighttpd2-4.0.3-IE2lYHc8mOPHjC6L8fNsLS
depends:
    array-0.5.4.0 async-2.2.5-7zRWRGcsDHK4x7TGVl8w2c
    auto-update-0.1.6-FWwEdBM4WUq2CmOnXBSdUp base-4.17.2.1
    byteorder-1.0.4-GnZZPnCtMLjHLa4McP5dl3 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-FZkso54i68UDZy9QWLkbnV
    conduit-1.3.6.1-DDryGYwytWSBiHNizsObtN
    conduit-extra-1.3.6-JXTqxUTNDEY6pYh4K0TNz1
    dhall-1.42.1-Hzn1y2kSjuY9PIwntn6xOv directory-1.3.7.1
    filepath-1.4.2.2 http-date-0.0.11-D3J2PImuYP3ELKHPAHGZpy
    http-types-0.12.4-679DcLxXQEvalr11Ew75E
    network-3.1.4.0-6CSLlS2XYBeLlFfm0MgCfu parsec-3.1.16.1
    resourcet-1.2.6-GnLJF89DOOQL8wsZDsu1Nb
    split-0.2.5-KcBaumhT6eFHklJKzsytdC
    streaming-commons-0.2.3.0-18n0yU3DoS0GNSvBxR5zoS text-2.0.2
    unix-2.7.3 unix-time-0.4.16-6XNkEunbRxSEoHJTfr64py
    unliftio-0.2.25.1-4ouS4p8u42FHJEBnZmJiqL
    unordered-containers-0.2.20-3jxCiK1Dn5HHqgJhQ3B9SH
    wai-3.2.4-9vtK1FVecfb2NcYZzev1ei
    wai-app-file-cgi-3.1.10-JTL2v2RKCQULogcjJFUh2V
    warp-3.3.30-LJ0UJXrkchWCYa3SEfy5Jz

haddock-interfaces:   /usr/share/doc/mighttpd2/html/mighttpd2.haddock
haddock-html:         /usr/share/doc/mighttpd2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
